Crate matchmaker

Crate matchmaker 

Re-exports

pub use errors::*;

Modules

action
binds
config
Config Types. See src/bin/mm/config.rs for an example
errors
event
message
noninteractive
nucleo
preview
render
tui
ui

Macros

acs
Example
bindmap
Example

Structs

Matchmaker
The main entrypoint of the library. To use:
OddEnds
PickOptions
Used to configure Matchmaker::pick with additional options.
Selector

Constants

MAX_ACTIONS
MAX_SPLITS

Traits

MatchResultExt
SSS
Thread safe (items and fns) These traits are required by Nucleo since it works in a different thread
Selection

Functions

make_previewer
Causes the program to display a preview of the active result. The Previewer can be connected to Matchmaker using PickOptions::previewer

Type Aliases

ActionAliaser
ActionExtHandler
ConfigInjector
ConfigMMItem
ConfigMatchmaker
Identifier
PasteHandler
Returns what should be pushed to input
RenderFn